@@ -1451,7 +1451,7 @@ class APFSDStrengthSolver(ABCSolver):
         p_data = self.preprocessed_data
         x_db_n = p_data['x_db_n']
         p_max = p_data['p_max']
-        if 0. < x < x_db_n:
+        if 0. <= x <= x_db_n:
             return p_max
         return 0.
 
